@@ -27,22 +27,19 @@ typedef enum fatAccessMode_t {
 } fatAccessMode_t;
 
 typedef struct Fs_t {
-	Class_t *Class;
-	int refs;
-	Stream_t *Next;
-	Stream_t *Buffer;
+	struct Stream_t head;
 
 	int serialized;
 	unsigned long serial_number;
-	unsigned int cluster_size;
+	uint8_t cluster_size;
 	uint16_t sector_size;
+	
 	int fat_error;
 
 	unsigned int (*fat_decode)(struct Fs_t *This, unsigned int num);
 	void (*fat_encode)(struct Fs_t *This, unsigned int num,
 			   unsigned int code);
 
-	Stream_t *Direct;
 	int fat_dirty;
 	uint16_t fat_start;
 	uint32_t fat_len;
@@ -86,6 +83,7 @@ typedef struct Fs_t {
 #define abs(x) ((unsigned int)((x)>0?(x):-(x)))
 #endif
 
+mt_off_t sectorsToBytes(Fs_t *This, uint32_t off);
 int fs_free(Stream_t *Stream);
 
 void set_fat(Fs_t *This);
